import { MDCDialog } from '@material/dialog/index';
let nextId = 0;
export class DetailDialog {
    constructor() {
        /**
         * Internal index used to differentiate multiple dialogs.
         */
        this.index = nextId++;
        /**
         * Array of the child `DetailDialogItem` elements.
         */
        this.detailItems = [];
        // @Prop() elementId = -1;
        /**
         * The title of the dialog window.
         */
        this.dialogTitle = 'Detail Dialog';
        /**
         * An array of strings that will be used to create action buttons for the
         * dialog.  When the corresponding button is clicked by the user, MDCDialog
         * will emit an event with the lowercase version of the action. For example
         * the action `Yes` would emit the `MDCDialog:closing` with the property
         * `event.detail.action === 'yes'`.
         */
        this.dialogActions = ['No', 'Yes'];
    }
    componentDidLoad() {
        this.dialog = new MDCDialog(this.root);
    }
    /**
     * Opens this dialog.
     */
    open() {
        this.dialog.open();
    }
    /**
     * Returns the values of all the DetailDialogItems as an array of
     * `MapElementDetails`
     */
    async getDetails() {
        const details = this.detailItems.map(async (item) => {
            const det = await item.getDetail();
            const rem = await item.toRemove();
            return Promise.resolve(Object.assign({}, det, { remove: rem }));
        });
        return details;
    }
    hostData() {
        return {
            class: {
                'mdc-dialog': true,
                'rl-detail-dialog': true,
            },
            role: 'alertdialog',
            'aria-modal': 'true',
            'aria-labelledby': `rl-detail-dialog__title-${this.index}`,
            'aria-describedby': `rl-detail_dialog__content-${this.index}`
        };
    }
    render() {
        this.detailItems = [];
        return ([
            h("div", { class: "mdc-dialog__container" },
                h("div", { class: "mdc-dialog__surface", style: { width: '60vw', height: '90vh' } },
                    h("h2", { class: "mdc-dialog__title", id: `rl-detail-dialog__title-${this.index}` }, this.dialogTitle),
                    h("div", { class: "mdc-dialog__content", id: `rl-detail-dialog__content-${this.index}` }, this.details && Object.values(this.details).map(detail => h("rl-detail-dialog-item", { detail: detail, categoryOptions: this.categories, ref: el => this.detailItems.push(el) }))),
                    h("button", { type: "button", class: "mdc-button" },
                        h("span", { class: "mdc-button__label", onClick: _ => this.addDetail.emit() }, "Add Detail")),
                    h("footer", { class: "mdc-dialog__actions" }, this.dialogActions.map(action => h("button", { class: "mdc-button mdc-dialog__button", "data-mdc-dialog-action": action.toLowerCase(), type: "button" },
                        h("span", { class: "mdc-button__label" }, action)))))),
            h("div", { class: "mdc-dialog__scrim" }),
        ]);
    }
    static get is() { return "rl-detail-dialog"; }
    static get properties() { return {
        "categories": {
            "type": "Any",
            "attr": "categories"
        },
        "details": {
            "type": "Any",
            "attr": "details"
        },
        "dialogActions": {
            "type": "Any",
            "attr": "dialog-actions"
        },
        "dialogTitle": {
            "type": String,
            "attr": "dialog-title"
        },
        "getDetails": {
            "method": true
        },
        "open": {
            "method": true
        },
        "root": {
            "elementRef": true
        }
    }; }
    static get events() { return [{
            "name": "addDetail",
            "method": "addDetail",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:rl-detail-dialog:**/"; }
}
