import { MDCSelect } from '@material/select/index';
let nextId = 0;
/**
 * A component that wraps a `Material Select Menu` component.
 */
export class Select {
    constructor() {
        /**
         * Internal ID used to differentiate multiple menus.
         */
        this.id = nextId++;
        /**
         * The label displayed on the select.
         */
        this.label = '';
        /**
         * An array of the different options displayed in the select menu.
         */
        this.options = [];
    }
    componentDidLoad() {
        this.select = new MDCSelect(this.root);
        this.select.listen('MDCSelect:change', () => this.selected.emit(this.select.selectedIndex));
    }
    componentDidUnload() {
        this.select.destroy();
    }
    hostData() {
        return {
            class: {
                'mdc-select': true,
            },
        };
    }
    render() {
        return ([
            h("i", { class: "mdc-select__dropdown-icon" }),
            h("select", { class: "mdc-select__native-control" }, this.options.map(option => {
                const o = option.toLowerCase();
                return option === this.selectedOption ?
                    h("option", { value: o, selected: true }, option) :
                    h("option", { value: o }, option);
            })),
            h("label", { class: "mdc-floating-label" }, this.label),
            h("div", { class: "mdc-line-ripple" }),
        ]);
    }
    static get is() { return "rl-select-menu"; }
    static get properties() { return {
        "label": {
            "type": String,
            "attr": "label"
        },
        "options": {
            "type": "Any",
            "attr": "options"
        },
        "root": {
            "elementRef": true
        },
        "selectedOption": {
            "type": String,
            "attr": "selected-option"
        }
    }; }
    static get events() { return [{
            "name": "selected",
            "method": "selected",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:rl-select-menu:**/"; }
}
